@@ -17,7 +17,7 @@
 # 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
 from paramiko.common import linefeed_byte_value, crlf, cr_byte, linefeed_byte, \
     cr_byte_value
-from paramiko.py3compat import BytesIO, PY2, u, bytes_types, text_type
+from paramiko.py3compat import BytesIO, PY2, u, b, bytes_types
 
 from paramiko.util import ClosingContextManager
 
@@ -370,11 +370,9 @@ class BufferedFile (ClosingContextManager):
         written yet.  (Use `flush` or `close` to force buffered data to be
         written out.)
 
-        :param str/bytes data: data to write
+        :param str data: data to write
         """
-        if isinstance(data, text_type):
-            # Accept text and encode as utf-8 for compatibility only.
-            data = data.encode('utf-8')
+        data = b(data)
         if self._closed:
             raise IOError('File is closed')
         if not (self._flags & self.FLAG_WRITE):
